@@ -28,6 +28,7 @@ import luigi
 from luigi.contrib.s3 import S3Target
 from six.moves import urllib
 import six
+import boto3
 
 import disdat.constants as constants
 import disdat.hyperframe_pb2 as hyperframe_pb2
@@ -267,6 +268,28 @@ class DataContext(object):
         else:
             return remote_ctxt_url[:-len('/context')]
 
+    @staticmethod
+    def extract_uuid_from_pb_path(pb_path, pb_type):
+        """
+        Extract the uuid that we put in each pb file name.
+        Both hframes and frames are <uuid>_frame.pb
+
+        Args:
+            pb_path(str):
+            pb_type(disdat.hyperframe.PBObject): either hyperframe.HyperFrameRecord or hyperframe.FrameRecord
+
+        Returns:
+            str: the uuid or None
+        """
+        if pb_type == hyperframe.FrameRecord:
+            frame_file_suffix = '_frame.pb'
+        elif pb_type == hyperframe.HyperFrameRecord:
+            frame_file_suffix = '_hframe.pb'
+        else:
+            assert False, "Unknown pb_type {} in extract_uuid_from_pb_path.".format(pb_type)
+        assert pb_path.endswith(frame_file_suffix)
+        return pb_path[:-len(frame_file_suffix)]
+
     def get_remote_object_dir(self):
         """
         Where objects live on remote.
@@ -293,8 +316,22 @@ class DataContext(object):
         """
         Currently a no-op.  Will connect to something like dynamodb
         when we have external indices for objects in cloud storage (aka S3).
+
+        Called when we first create a data_context object.
+        At this point it may or may not have a remote.
+        If we have a remote, then we assume AWS access.
+        If we have AWS access, then we try to associate with dynamo.
+
         """
-        pass
+        if self.remote_ctxt_url is None:
+            return
+
+        if not self.remote_engine:
+            try:
+                self.remote_engine = boto3.resource('dynamodb', endpoint_url="http://localhost:8000")
+            except Exception as e:
+                print("Failed to get dynamo AWS resource: {}".format(e))
+        return
 
     def init_local_db(self, in_memory=False):
         """
@@ -333,6 +370,42 @@ class DataContext(object):
         self.dbck()
         return
 
+    @staticmethod
+    def _weak_validate_hframe(hfr, found_frames_uuids):
+        """
+        This weakly validates the hframe.  First this is mainly called when we are rebuilding the
+        database.  It is the case that occasionally the s3 copy does not copy down the frames (something
+        to investigate).  In that case we do not want to index a hyperframe that is not complete on disk.
+
+        But, to do a full check means we have to read each and every protocol buffer file.  When there
+        are very large contexts (with 18 million pb's), this can take a long time.  Especially running
+        on containers connected to EBS volumes with a limited budget of IO's.
+
+        We make sure that there is a file path with the listed frame's UUID found
+        inside the hframe.   But unlike _validate_hframe we do not validate the contents
+        of the frame itself.  That is we do not look for each of the files the frame
+        may refer to.
+
+        NOTE: Only call this from rebuild_db to avoid more file reads than necessary.
+        TODO: Implement dbck that can check the db on a machine with a dedicated ssd/nvm store.
+
+        Args:
+            hfr:
+            found_frames_uuids (dict[str]): dict of frame uuids that exist on disk.
+
+        Returns:
+            bool: true if hframe passes weak test.
+
+        """
+        for str_tuple in hfr.pb.frames:
+            fr_name = str_tuple.k
+            fr_uuid = str_tuple.v
+            if fr_uuid not in found_frames_uuids:
+                # Frame was not on disk
+                _logger.warn("HyperFrame {} Frame {} {} not present on disk".format(hfr.pb.uuid, fr_name, fr_uuid))
+                return False
+        return True
+
     @staticmethod
     def _validate_hframe(hfr, found_frames, found_auths):
         """
@@ -349,7 +422,7 @@ class DataContext(object):
         b.) could be in the process of being written to disk (another process)
 
         NOTE:  We bounce out early at the first inconsistency.  We do not record
-        what wasn't correct.   TODO's.
+        what wasn't correct.
 
         Args:
             hfr (`HyperFrameRecord`):
@@ -357,8 +430,7 @@ class DataContext(object):
             found_auths:
 
         Returns:
-            valid (bool): This hframe_record corresponds to what we have on disk
-
+            bool: This hframe_record corresponds to what we have on disk
         """
 
         for str_tuple in hfr.pb.frames:
@@ -426,14 +498,12 @@ class DataContext(object):
         For this context, read in all pb's and rebuild tables.
         All state is immutable.
         1.) Read in all HFrame PBs
-        2.) Ensure that each HFrame PB is consistent -- it was completely written
-        to disk.
+        2.) Ensure that each HFrame PB is WEAKLY consistent -- file names corresponding to the
+        frames are on disk (but we do not check their contents or whether the file links exist).
         3.) A.) If yes, try to insert into db if it doesn't already exist.
             B.) If not consistent and not in db, leave it.  Could be concurrent add.
             C.) If not consistent and in db as 'valid', mark db entry as 'invalid'
 
-        dbck does the opposite process.  It will read the DB and see
-
         Args:
             ignore_existing (bool): If True, we ignore existing records (do not update). Else UPSERT on existing.
 
@@ -441,53 +511,41 @@ class DataContext(object):
             num errors (int):
 
         """
+        INSERT_BATCH = 1000
         hframes = {}
         frames = {}
-        auths = {}
 
         pb_types = [('*_hframe.pb', hyperframe.HyperFrameRecord, hframes),
-                    ('*_frame.pb', hyperframe.FrameRecord, frames),
-                    ('*_auth.pb', hyperframe.LinkAuthBase, auths)]
+                    ('*_frame.pb', hyperframe.FrameRecord, frames)]
 
-        # Make all the tables first.
-        for glb, rcd_type, store in pb_types:
-            rcd_type.create_table(self.local_engine)
+        # Note: we no longer create the frame and auth tables.
+        hyperframe.HyperFrameRecord.create_table(self.local_engine)
 
         for uuid_dir in os.listdir(self.get_object_dir()):
             for glb, rcd_type, store in pb_types:
                 files = glob.glob(os.path.join(os.path.join(self.get_object_dir(), uuid_dir), glb))
                 for f in files:
-                    # hyperframes, frames, and links all have uuid fields
-                    rcd = hyperframe.r_pb_fs(f, rcd_type)
-                    store[rcd.pb.uuid] = rcd
+                    if rcd_type == hyperframe.HyperFrameRecord:
+                        rcd = hyperframe.r_pb_fs(f, rcd_type)
+                        store[rcd.pb.uuid] = rcd
+                    elif rcd_type == hyperframe.FrameRecord:
+                        base_f = os.path.basename(f)
+                        store[DataContext.extract_uuid_from_pb_path(base_f, rcd_type)] = True
 
         hframe_count = len(hframes.values())
         ten_percent = max(1, int(hframe_count / 10))
         perc = 0
+        insert_batch = []
         for i, hfr in enumerate(hframes.values()):
             if i % ten_percent == 0:
                 print("Disdat DB rebuild: written {} ({} percent) to db".format(i, perc))
                 perc += 10
-
-            if DataContext._validate_hframe(hfr, frames, auths):
-                # looks like a good hyperframe
-                # see if it exists, if it does do not write hframe and assume frames are also present
-                # if ignore_existing==False, then we will try to insert into DB anyhow.
+            if DataContext._weak_validate_hframe(hfr, frames):
                 hfr_from_db_list = hyperframe.select_hfr_db(self.local_engine, uuid=hfr.pb.uuid)
                 if not ignore_existing or len(hfr_from_db_list) == 0:
-                    hyperframe.w_pb_db(hfr, self.local_engine)
-                    for str_tuple in hfr.pb.frames:
-                        fr_uuid = str_tuple.v
-                        hfr_from_db_list = hyperframe.select_hfr_db(self.local_engine, uuid=fr_uuid)
-                        if not ignore_existing or len(hfr_from_db_list) == 0:
-                            # The frame pb doesn't store the hfr_uuid, but the db
-                            # does.  Since we are reading from disk, we need to
-                            # set it back into the FrameRecord.
-                            frames[fr_uuid].hframe_uuid = hfr.pb.uuid
-                            hyperframe.w_pb_db(frames[fr_uuid], self.local_engine)
+                    insert_batch.append(hfr)
             else:
                 # invalid hyperframe, if present in db as valid, mark invalid
-                # Try to read it in
                 hfr_from_db_list = hyperframe.select_hfr_db(self.local_engine, uuid=hfr.pb.uuid)
                 assert(len(hfr_from_db_list) == 0 or len(hfr_from_db_list) == 1)
                 if len(hfr_from_db_list) == 1:
@@ -497,10 +555,11 @@ class DataContext(object):
                         hyperframe.update_hfr_db(self.local_engine, hyperframe.RecordState.invalid,
                                                  uuid=hfr.pb.uuid)
                     # else, pending, invalid, deleted is all OK with an invalid hyperframe
-
-        #print "hframes {}".format(hframes)
-        #print "frames {}".format(frames)
-        #print "auths {}".format(auths)
+            if len(insert_batch) >= INSERT_BATCH:
+                hyperframe.w_pb_db(insert_batch, self.local_engine)
+                insert_batch = []
+        if len(insert_batch) > 0:
+            hyperframe.w_pb_db(insert_batch, self.local_engine)
 
     def bundle_count(self):
         """ Determine how many bundles in the current local context
@@ -614,7 +673,7 @@ class DataContext(object):
                 self.rm_db_links(hfr[0], dry_run=False)
                 shutil.rmtree(self.implicit_hframe_path(hfr_uuid))
                 hyperframe.delete_hfr_db(self.local_engine, uuid=hfr_uuid)
-                hyperframe.delete_fr_db(self.local_engine, hfr_uuid)
+                #hyperframe.delete_fr_db(self.local_engine, hfr_uuid) -- frames table depricated
             else:
                 print ("Disdat: Looks like you're trying to remove a committed bundle with a db link backing a view.")
                 print ("Disdat: Removal of this bundle with db links that back a view requires '--force'")
@@ -625,7 +684,7 @@ class DataContext(object):
 
             # Must clean up db if directory removal failed
             hyperframe.delete_hfr_db(self.local_engine, uuid=hfr_uuid, state=hyperframe.RecordState.deleted)
-            hyperframe.delete_fr_db(self.local_engine, hfr_uuid)
+            #hyperframe.delete_fr_db(self.local_engine, hfr_uuid) -- frames table depricated
 
             return False
 
@@ -677,10 +736,6 @@ class DataContext(object):
         """
         hyperframe.w_pb_db(hfr, self.local_engine)
 
-        # Write DB Frames
-        for fr in hfr.get_frames(self):
-            hyperframe.w_pb_db(fr, self.local_engine)
-
     def _write_hframe_local(self, hfr):
         """
 
@@ -701,10 +756,6 @@ class DataContext(object):
         # Write FS HyperFrame
         hyperframe.w_pb_fs(os.path.join(self.get_object_dir(), hfr.pb.uuid), hfr)
 
-        # Write DB Frames
-        for fr in hfr.get_frames(self):
-            hyperframe.w_pb_db(fr, self.local_engine)
-
         # Todo: Make it an option
         # Note: We are changing the default human_name to be only the task name
         # self.prune_uncommitted_history(hfr.pb.human_name)
